.. toctree::
    :caption: Contributor docs
    :maxdepth: 1

    contributing/index
    contributing/start
    contributing/code
    contributing/debugging
    contributing/internals
    contributing/addons
    contributing/frontend
    contributing/issues
    contributing/tests
    contributing/schemas
    contributing/release
    contributing/security
    contributing/about
    contributing/license
